MEWpy
======

MEWpy is an integrated Metabolic Engineering Workbench for strain design optimization. 
It offers methods to explore different classes of constraint-based models (CBM) for:

- Simulation: allows to simulate of steady-state metabolic models, considering different formulations (e.g., GECKO, ETFL) and kinetic models;
- Optimization: performs Evolutionary Computation based strain design optimization by knocking out (KO) or over/under expressing (OU) reactions, genes, or enzymes.
- Omics data integration (eFlux, GIMME, iMAT);
- Regulatory networks integration (rFBA, srFBA)

MEWPy currently supports REFRAMED and COBRApy simulation environments. 

Documentation
~~~~~~~~~~~~~

For documentation and API please check: `https://mewpy.readthedocs.io <https://mewpy.readthedocs.io>`_


Installation
~~~~~~~~~~~~

pip install mewpy


Credits and License
~~~~~~~~~~~~~~~~~~~

Developed at:
-  Centre of Biological Engineering, University of Minho (2019-)

